@@ -1,4 +1,4 @@
-﻿define(['dialogHelper', 'jQuery', 'emby-button', 'listViewStyle', 'paper-icon-button-light'], function (dialogHelper, $) {
+﻿define(['dialogHelper', 'dom', 'components/libraryoptionseditor/libraryoptionseditor', 'emby-button', 'listViewStyle', 'paper-icon-button-light', 'formDialogStyle'], function (dialogHelper, dom, libraryoptionseditor) {
 
     var currentDeferred;
     var hasChanges;
@@ -41,7 +41,7 @@
                 ApiClient.removeMediaPath(virtualFolder.Name, location, refreshAfterChange).then(function () {
 
                     hasChanges = true;
-                    refreshLibraryFromServer($(button).parents('.editorContent')[0]);
+                    refreshLibraryFromServer(dom.parentWithClass(button, 'dlg-libraryeditor'));
 
                 }, function () {
 
@@ -67,7 +67,7 @@
         html += '</h3>';
         html += '</div>';
 
-        html += '<button is="paper-icon-button-light" class="btnRemovePath" data-index="' + index + '"><i class="md-icon">remove_circle</i></button>';
+        html += '<button is="paper-icon-button-light" class="listItemButton btnRemovePath" data-index="' + index + '"><i class="md-icon">remove_circle</i></button>';
 
         html += '</div>';
 
@@ -96,12 +96,15 @@
 
         page.querySelector('.folderList').innerHTML = foldersHtml;
 
-        $(page.querySelectorAll('.btnRemovePath')).on('click', onRemoveClick);
+        var btnRemovePath = page.querySelectorAll('.btnRemovePath');
+        for (var i = 0, length = btnRemovePath.length; i < length; i++) {
+            btnRemovePath[i].addEventListener('click', onRemoveClick);
+        }
     }
 
     function onAddButtonClick() {
 
-        var page = $(this).parents('.editorContent')[0];
+        var page = dom.parentWithClass(this, 'dlg-libraryeditor');
 
         require(['directorybrowser'], function (directoryBrowser) {
 
@@ -121,16 +124,30 @@
         });
     }
 
-    function initEditor(page, options) {
-        renderLibrary(page, options);
+    function initEditor(dlg, options) {
+        renderLibrary(dlg, options);
 
-        $('.btnAddFolder', page).on('click', onAddButtonClick);
+        dlg.querySelector('.btnAddFolder').addEventListener('click', onAddButtonClick);
+
+        libraryoptionseditor.embed(dlg.querySelector('.libraryOptions'), options.library.CollectionType, options.library.LibraryOptions);
+    }
+
+    function onDialogClosing() {
+
+        var dlg = this;
+
+        var libraryOptions = libraryoptionseditor.getLibraryOptions(dlg.querySelector('.libraryOptions'));
+
+        ApiClient.updateVirtualFolderOptions(currentOptions.library.ItemId, libraryOptions);
     }
 
     function onDialogClosed() {
 
-        $(this).remove();
         Dashboard.hideLoadingMsg();
+
+        // hardcoding this to true for now until libraryOptions are taken into account
+        hasChanges = true;
+
         currentDeferred.resolveWith(null, [hasChanges]);
     }
 
@@ -156,40 +173,33 @@
                     size: 'small',
 
                     // In (at least) chrome this is causing the text field to not be editable
-                    modal: false
+                    modal: false,
+                    removeOnClose: true
                 });
 
+                dlg.classList.add('dlg-libraryeditor');
                 dlg.classList.add('ui-body-a');
                 dlg.classList.add('background-theme-a');
-                dlg.classList.add('popupEditor');
 
-                var html = '';
-                html += '<h2 class="dialogHeader">';
-                html += '<button type="button" is="emby-button" icon="arrow-back" class="fab mini btnCloseDialog" tabindex="-1"><i class="md-icon">arrow_back</i></button>';
+                dlg.innerHTML = Globalize.translateDocument(template);
 
-                html += '<div style="display:inline-block;margin-left:.6em;vertical-align:middle;">' + options.library.Name + '</div>';
-                html += '</h2>';
+                dlg.querySelector('.formDialogHeaderTitle').innerHTML = options.library.Name;
 
-                html += '<div class="editorContent" style="max-width:800px;margin:auto;">';
-                html += Globalize.translateDocument(template);
-                html += '</div>';
-
-                dlg.innerHTML = html;
                 document.body.appendChild(dlg);
 
-                var editorContent = dlg.querySelector('.editorContent');
-                initEditor(editorContent, options);
+                initEditor(dlg, options);
 
-                $(dlg).on('close', onDialogClosed);
+                dlg.addEventListener('closing', onDialogClosing);
+                dlg.addEventListener('close', onDialogClosed);
 
                 dialogHelper.open(dlg);
 
-                $('.btnCloseDialog', dlg).on('click', function () {
+                dlg.querySelector('.btnCancel').addEventListener('click', function () {
 
                     dialogHelper.close(dlg);
                 });
 
-                refreshLibraryFromServer(editorContent);
+                refreshLibraryFromServer(dlg);
             }
 
             xhr.send();
