@@ -64,7 +64,7 @@
 
             if (positive && positive.length > 0) {
 
-                html += '<div data-role="collapsible" data-collapsed="true" style="margin-top: 2em;" >';
+                html += '<div style="margin-top: 2em;" >';
                 html += '<h3>' + Globalize.translate('HeaderLatestReviews') + '</h3>';
 
                 html += "<div><br/>";
@@ -73,10 +73,10 @@
                     var review = positive[i];
 
                     html += "<div>";
-                    html += "<span class='storeItemReviewText'>";
+                    html += "<span class='storeItemReviewText' style='display:inline-flex;align-items:center;'>";
                     html += new Date(review.timestamp).toDateString();
                     if (review.rating) {
-                        html += '<iron-icon icon="star" style="color:#666;height:20px;width:20px;min-height:20px;min-width:20px;margin-right:.25em;"></iron-icon>';
+                        html += '<i class="md-icon" style="color:#cc3333;height:auto;width:auto;margin-left:.5em;">star</i>';
                         html += review.rating.toFixed(1);
                     }
                     html += " " + review.title;
@@ -98,6 +98,99 @@
         });
     }
 
+    function renderPluginInfo(page, pkg, pluginSecurityInfo) {
+
+        if (AppInfo.isNativeApp) {
+            return;
+        }
+
+        require(['jQuery'], function ($) {
+            if (pkg.isPremium) {
+                $('.premiumPackage', page).show();
+
+                // Fill in registration info
+                var regStatus = "";
+                if (pkg.isRegistered) {
+
+                    regStatus += "<p style='color:green;'>";
+
+                    regStatus += Globalize.translate('MessageFeatureIncludedWithSupporter');
+
+                } else {
+
+                    var expDateTime = new Date(pkg.expDate).getTime();
+                    var nowTime = new Date().getTime();
+
+                    if (expDateTime <= nowTime) {
+                        regStatus += "<p style='color:red;'>";
+                        regStatus += Globalize.translate('MessageTrialExpired');
+                    } else if (expDateTime > new Date(1970, 1, 1).getTime()) {
+
+                        regStatus += "<p style='color:blue;'>";
+                        regStatus += Globalize.translate('MessageTrialWillExpireIn').replace('{0}', Math.round(expDateTime - nowTime) / (86400000));
+                    }
+                }
+
+                regStatus += "</p>";
+                $('#regStatus', page).html(regStatus);
+
+                if (pluginSecurityInfo.IsMBSupporter) {
+                    $('#regInfo', page).html(pkg.regInfo || "");
+
+                    $('.premiumDescription', page).hide();
+                    $('.supporterDescription', page).hide();
+
+                    if (pkg.price > 0) {
+
+                        $('.premiumHasPrice', page).show();
+                        $('#featureId', page).val(pkg.featureId);
+                        $('#featureName', page).val(pkg.name);
+                        $('#amount', page).val(pkg.price);
+
+                        $('#regPrice', page).html("<h3>" + Globalize.translate('ValuePriceUSD').replace('{0}', "$" + pkg.price.toFixed(2)) + "</h3>");
+                        $('#ppButton', page).hide();
+
+                        var url = "https://mb3admin.com/admin/service/user/getPayPalEmail?id=" + pkg.owner;
+
+                        fetch(url).then(function (response) {
+
+                            return response.json();
+
+                        }).then(function (dev) {
+
+                            if (dev.payPalEmail) {
+                                $('#payPalEmail', page).val(dev.payPalEmail);
+                                $('#ppButton', page).show();
+
+                            }
+                        });
+
+                    } else {
+                        // Supporter-only feature
+                        $('.premiumHasPrice', page).hide();
+                    }
+                } else {
+
+                    if (pkg.price) {
+                        $('.premiumDescription', page).show();
+                        $('.supporterDescription', page).hide();
+                        $('#regInfo', page).html("");
+
+                    } else {
+                        $('.premiumDescription', page).hide();
+                        $('.supporterDescription', page).show();
+                        $('#regInfo', page).html("");
+                    }
+
+                    $('#ppButton', page).hide();
+                }
+
+            } else {
+                $('.premiumPackage', page).hide();
+            }
+        });
+    }
+
     function renderPackage(pkg, installedPlugins, pluginSecurityInfo, page) {
 
         var installedPlugin = installedPlugins.filter(function (ip) {
@@ -133,12 +226,12 @@
 
         $('#developer', page).html(pkg.owner);
 
-        RegistrationServices.renderPluginInfo(page, pkg, pluginSecurityInfo);
+        renderPluginInfo(page, pkg, pluginSecurityInfo);
 
         //Ratings and Reviews
         var ratingHtml = '';
         if (pkg.avgRating) {
-            ratingHtml += '<iron-icon icon="star" style="color:#666;height:20px;width:20px;min-height:20px;min-width:20px;margin-right:.25em;"></iron-icon>';
+            ratingHtml += '<i class="md-icon" style="color:#cc3333;height:auto;width:auto;">star</i>';
             ratingHtml += pkg.avgRating.toFixed(1);
         }
         ratingHtml += "<span>";
