@@ -1,4 +1,4 @@
-﻿define(['imageLoader', 'layoutManager', 'viewManager', 'navdrawer', 'paper-icon-button-light', 'material-icons'], function (imageLoader, layoutManager, viewManager, navdrawer) {
+﻿define(['imageLoader', 'layoutManager', 'viewManager', 'navdrawer', 'libraryBrowser', 'apphost', 'paper-icon-button-light', 'material-icons'], function (imageLoader, layoutManager, viewManager, navdrawer, libraryBrowser, appHost) {
 
     var navDrawerElement = document.querySelector('.mainDrawer');
     var navDrawerScrollContainer = navDrawerElement.querySelector('.scrollContainer');
@@ -9,12 +9,12 @@
         var html = '';
 
         html += '<div class="primaryIcons">';
-        var backIcon = browserInfo.safari ? 'chevron_left' : 'arrow_back';
+        var backIcon = browserInfo.safari ? 'chevron_left' : '&#xE5C4;';
 
         html += '<button type="button" is="paper-icon-button-light" class="headerButton headerButtonLeft headerBackButton hide autoSize"><i class="md-icon">' + backIcon + '</i></button>';
 
         html += '<button type="button" is="paper-icon-button-light" class="headerButton mainDrawerButton barsMenuButton headerButtonLeft autoSize"><i class="md-icon">menu</i></button>';
-        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerAppsButton barsMenuButton headerButtonLeft autoSize"><i class="md-icon">menu</i></button>';
+        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerAppsButton barsMenuButton headerButtonLeft autoSize"><i class="md-icon">home</i></button>';
 
         html += '<div class="libraryMenuButtonText headerButton">' + Globalize.translate('ButtonHome') + '</div>';
 
@@ -40,7 +40,7 @@
         html += '</div>';
         html += '</div>';
 
-        html += '<div class="viewMenuBarTabs hiddenScrollX">';
+        html += '<div class="viewMenuBarTabs">';
         html += '</div>';
 
         var viewMenuBar = document.createElement('div');
@@ -57,12 +57,7 @@
 
     function onBackClick() {
 
-        if (Dashboard.exitOnBack()) {
-            Dashboard.exit();
-        }
-        else {
-            history.back();
-        }
+        Emby.Page.back();
     }
 
     function updateUserInHeader(user) {
@@ -140,9 +135,9 @@
                 }
             }
 
-            require(['voice/voice'], function (voice) {
+            require(['apphost'], function (apphost) {
 
-                if (voice.isSupported()) {
+                if (apphost.supports('voiceinput')) {
                     header.querySelector('.headerVoiceButton').classList.remove('hide');
                 } else {
                     header.querySelector('.headerVoiceButton').classList.add('hide');
@@ -164,8 +159,8 @@
     }
 
     function showVoice() {
-        require(['voice/voice'], function (voice) {
-            voice.startListening();
+        require(['voiceDialog'], function (voiceDialog) {
+            voiceDialog.showDialog();
         });
     }
 
@@ -179,57 +174,7 @@
 
     function onHeaderAppsButtonClick() {
 
-        require(['dialogHelper'], function (dialogHelper) {
-
-            var dlg = dialogHelper.createDialog({
-                removeOnClose: true,
-                modal: false,
-                autoFocus: false,
-                entryAnimationDuration: 160,
-                exitAnimationDuration: 160,
-                enableHistory: false
-            });
-
-            dlg.classList.add('ui-body-a');
-            dlg.classList.add('background-theme-a');
-            dlg.classList.add('adminAppsMenu');
-
-            var html = '';
-
-            html += '<div class="adminAppsMenuRow">';
-
-            html += '<a class="adminAppsButton" href="home.html">';
-            html += '<button is="paper-icon-button-light" class="autoSize"><i class="md-icon">home</i></button>';
-            html += '<div>' + Globalize.translate('ButtonHome') + '</div>';
-            html += '</a>';
-
-            html += '</div>';
-
-            html += '<div class="adminAppsMenuRow">';
-
-            html += '<a class="adminAppsButton" href="edititemmetadata.html">';
-            html += '<button is="paper-icon-button-light" class="autoSize"><i class="md-icon">mode_edit</i></button>';
-            html += '<div>' + Globalize.translate('ButtonMetadataManager') + '</div>';
-            html += '</a>';
-            html += '<a class="adminAppsButton" href="reports.html">';
-            html += '<button is="paper-icon-button-light" class="autoSize"><i class="md-icon">insert_chart</i></button>';
-            html += '<div>' + Globalize.translate('ButtonReports') + '</div>';
-            html += '</a>';
-
-            html += '</div>';
-
-            dlg.innerHTML = html;
-            document.body.appendChild(dlg);
-
-            dlg.addEventListener('click', function (e) {
-                var link = parentWithTag(e.target, 'A');
-                if (link) {
-                    dialogHelper.close(dlg);
-                }
-            });
-            dialogHelper.open(dlg);
-
-        });
+        Dashboard.navigate('home.html');
     }
 
     function bindMenuEvents() {
@@ -275,7 +220,7 @@
 
     function getItemHref(item, context) {
 
-        return LibraryBrowser.getHref(item, context);
+        return libraryBrowser.getHref(item, context);
     }
 
     var requiresUserRefresh = true;
@@ -324,7 +269,7 @@
         var homeHref = window.ApiClient ? 'home.html' : 'selectserver.html?showuser=1';
 
         html += '<a class="lnkMediaFolder sidebarLink" href="' + homeHref + '" onclick="return LibraryMenu.onLinkClicked(event, this);">';
-        html += '<div style="background-image:url(\'css/images/mblogoicon.png\');width:' + 28 + 'px;height:' + 28 + 'px;background-size:contain;background-repeat:no-repeat;background-position:center center;border-radius:1000px;vertical-align:middle;margin:0 1.85em 0 1.55em;display:inline-block;"></div>';
+        html += '<div style="background-image:url(\'css/images/mblogoicon.png\');width:' + 28 + 'px;height:' + 28 + 'px;background-size:contain;background-repeat:no-repeat;background-position:center center;border-radius:1000px;vertical-align:middle;margin:0 1.25em 0 1.55em;display:inline-block;"></div>';
         html += Globalize.translate('ButtonHome');
         html += '</a>';
 
@@ -346,7 +291,7 @@
             html += '</div>';
 
             html += '<a class="sidebarLink lnkMediaFolder lnkManageServer" data-itemid="dashboard" href="#"><i class="md-icon sidebarLinkIcon">dashboard</i><span class="sidebarLinkText">' + Globalize.translate('ButtonManageServer') + '</span></a>';
-            html += '<a class="sidebarLink lnkMediaFolder editorViewMenu" data-itemid="editor" onclick="return LibraryMenu.onLinkClicked(event, this);" href="edititemmetadata.html"><i class="md-icon sidebarLinkIcon">mode_edit</i><span class="sidebarLinkText">' + Globalize.translate('ButtonMetadataManager') + '</span></a>';
+            html += '<a class="sidebarLink lnkMediaFolder editorViewMenu" data-itemid="editor" onclick="return LibraryMenu.onLinkClicked(event, this);" href="edititemmetadata.html"><i class="md-icon sidebarLinkIcon">mode_edit</i><span class="sidebarLinkText">' + Globalize.translate('MetadataManager') + '</span></a>';
 
             if (!browserInfo.mobile) {
                 html += '<a class="sidebarLink lnkMediaFolder" data-itemid="reports" onclick="return LibraryMenu.onLinkClicked(event, this);" href="reports.html"><i class="md-icon sidebarLinkIcon">insert_chart</i><span class="sidebarLinkText">' + Globalize.translate('ButtonReports') + '</span></a>';
@@ -362,7 +307,9 @@
             html += '<a class="sidebarLink lnkMediaFolder lnkMySettings" onclick="return LibraryMenu.onLinkClicked(event, this);" href="mypreferencesmenu.html?userId=' + user.localUser.Id + '"><i class="md-icon sidebarLinkIcon">settings</i><span class="sidebarLinkText">' + Globalize.translate('ButtonSettings') + '</span></a>';
         }
 
-        html += '<a class="sidebarLink lnkMediaFolder lnkMySync" data-itemid="mysync" onclick="return LibraryMenu.onLinkClicked(event, this);" href="mysync.html"><i class="md-icon sidebarLinkIcon">sync</i><span class="sidebarLinkText">' + Globalize.translate('ButtonSync') + '</span></a>';
+        html += '<a class="sidebarLink lnkMediaFolder lnkManageOffline" data-itemid="manageoffline" onclick="return LibraryMenu.onLinkClicked(event, this);" href="mysync.html?mode=offline"><i class="md-icon sidebarLinkIcon">file_download</i><span class="sidebarLinkText">' + Globalize.translate('ManageOfflineDownloads') + '</span></a>';
+
+        html += '<a class="sidebarLink lnkMediaFolder lnkSyncToOtherDevices" data-itemid="syncotherdevices" onclick="return LibraryMenu.onLinkClicked(event, this);" href="mysync.html"><i class="md-icon sidebarLinkIcon">sync</i><span class="sidebarLinkText">' + Globalize.translate('SyncToOtherDevices') + '</span></a>';
 
         if (Dashboard.isConnectMode()) {
             html += '<a class="sidebarLink lnkMediaFolder" data-itemid="selectserver" onclick="return LibraryMenu.onLinkClicked(event, this);" href="selectserver.html?showuser=1"><i class="md-icon sidebarLinkIcon">wifi</i><span class="sidebarLinkText">' + Globalize.translate('ButtonSelectServer') + '</span></a>';
@@ -391,19 +338,6 @@
         }
     }
 
-    function parentWithTag(elem, tagName) {
-
-        while (elem.tagName != tagName) {
-            elem = elem.parentNode;
-
-            if (!elem) {
-                return null;
-            }
-        }
-
-        return elem;
-    }
-
     function updateDashboardMenuSelectedItem() {
 
         var links = navDrawerScrollContainer.querySelectorAll('.sidebarLink');
@@ -510,15 +444,22 @@
 
         if (!user) {
 
-            showBySelector('.lnkMySync', false);
+            showBySelector('.lnkManageOffline', false);
+            showBySelector('.lnkSyncToOtherDevices', false);
             showBySelector('.userMenuOptions', false);
             return;
         }
 
         if (user.Policy.EnableSync) {
-            showBySelector('.lnkMySync', true);
+            showBySelector('.lnkSyncToOtherDevices', true);
         } else {
-            showBySelector('.lnkMySync', false);
+            showBySelector('.lnkSyncToOtherDevices', false);
+        }
+
+        if (user.Policy.EnableSync && appHost.supports('sync')) {
+            showBySelector('.lnkManageOffline', true);
+        } else {
+            showBySelector('.lnkManageOffline', false);
         }
 
         var userId = Dashboard.getCurrentUserId();
@@ -708,25 +649,30 @@
                 viewMenuBarTabs.classList.remove('hide');
             }
 
-            if (LibraryMenu.tabType != type) {
+            require(['emby-tabs', 'emby-button'], function () {
+                if (LibraryMenu.tabType != type) {
 
-                require(['paper-tabs'], function () {
+                    var index = 0;
 
-                    var noInk = browserInfo.animate ? '' : ' noink';
+                    viewMenuBarTabs.innerHTML = '<div is="emby-tabs"><div class="emby-tabs-slider">' + builder().map(function (t) {
 
-                    viewMenuBarTabs.innerHTML = '<paper-tabs selected="' + selectedIndex + '" hidescrollbuttons ' + noInk + '>' + builder().map(function (t) {
+                        var tabClass = selectedIndex == index ? 'emby-tab-button emby-tab-button-active' : 'emby-tab-button';
 
-                        return '<paper-tab link><a class="clearLink paperTabLink" href="' + t.href + '"><div>' + t.name + '</div></a></paper-tab>';
+                        var tabHtml = '<button onclick="Dashboard.navigate(this.getAttribute(\'data-href\'));" data-href="' + t.href + '" is="emby-button" class="' + tabClass + '" data-index="' + index + '"><div class="emby-button-foreground">' + t.name + '</div></button>';
+                        index++;
+                        return tabHtml;
+
+                    }).join('') + '</div></div>';
 
-                    }).join('') + '</paper-tabs>';
                     document.body.classList.add('withTallToolbar');
                     LibraryMenu.tabType = type;
-                });
-                return;
-            }
+                    return;
+                }
 
-            viewMenuBarTabs.querySelector('paper-tabs').selected = selectedIndex;
-            LibraryMenu.tabType = type;
+                viewMenuBarTabs.querySelector('[is="emby-tabs"]').selectedIndex(selectedIndex);
+
+                LibraryMenu.tabType = type;
+            });
         },
 
         setTitle: function (title) {
@@ -846,7 +792,12 @@
             else if (isReportsPage && itemId == 'reports') {
                 lnkMediaFolder.classList.add('selectedMediaFolder');
             }
-            else if (isMySyncPage && itemId == 'mysync') {
+            else if (isMySyncPage && itemId == 'manageoffline' && window.location.href.toString().indexOf('mode=offline') != -1) {
+
+                lnkMediaFolder.classList.add('selectedMediaFolder');
+            }
+            else if (isMySyncPage && itemId == 'syncotherdevices' && window.location.href.toString().indexOf('mode=offline') == -1) {
+
                 lnkMediaFolder.classList.add('selectedMediaFolder');
             }
             else if (id && itemId == id) {
@@ -858,33 +809,6 @@
         }
     }
 
-    function updateTabLinks(page) {
-
-        var elems = page.querySelectorAll('.scopedLibraryViewNav a');
-
-        var id = page.classList.contains('liveTvPage') || page.classList.contains('channelsPage') || page.classList.contains('metadataEditorPage') || page.classList.contains('reportsPage') || page.classList.contains('mySyncPage') || page.classList.contains('allLibraryPage') ?
-            '' :
-            getTopParentId() || '';
-
-        if (!id) {
-            return;
-        }
-
-        for (i = 0, length = elems.length; i < length; i++) {
-
-            var lnk = elems[i];
-            var src = lnk.href;
-
-            if (src.indexOf('#') != -1) {
-                continue;
-            }
-
-            src = replaceQueryString(src, 'topParentId', id);
-
-            lnk.href = src;
-        }
-    }
-
     function onWebSocketMessage(e, data) {
 
         var msg = data;
@@ -921,21 +845,6 @@
         }
     }
 
-    pageClassOn('pageinit', 'page', function () {
-
-        var page = this;
-
-        var isLibraryPage = page.classList.contains('libraryPage');
-
-        if (isLibraryPage) {
-
-            var navs = page.querySelectorAll('.libraryViewNav');
-            for (var i = 0, length = navs.length; i < length; i++) {
-                initHeadRoom(navs[i]);
-            }
-        }
-    });
-
     pageClassOn('pagebeforeshow', 'page', function (e) {
 
         var page = this;
@@ -953,20 +862,15 @@
 
         if (isDashboardPage) {
             refreshDashboardInfoInDrawer(page);
-            //mainDrawerPanel.forceNarrow = false;
         } else {
-
             if (navDrawerElement.classList.contains('adminDrawer')) {
                 refreshLibraryDrawer();
             }
-
-            //mainDrawerPanel.forceNarrow = true;
         }
 
         setDrawerClass(page);
 
         updateViewMenuBar(page);
-        updateTabLinks(page);
 
         if (!e.detail.isRestored) {
             // Scroll back up so in case vertical scroll was messed with
@@ -1041,18 +945,9 @@
             return;
         }
 
-        require(["headroom"], function () {
+        require(["headroom-window"], function (headroom) {
 
-            // construct an instance of Headroom, passing the element
-            var headroom = new Headroom(elem, {
-                // or scroll tolerance per direction
-                tolerance: {
-                    down: 40,
-                    up: 0
-                }
-            });
-            // initialise
-            headroom.init();
+            headroom.add(elem);
         });
     }
 
@@ -1105,8 +1000,8 @@
         var drawerWidth = screen.availWidth - 50;
         // At least 240
         drawerWidth = Math.max(drawerWidth, 240);
-        // But not exceeding 270
-        drawerWidth = Math.min(drawerWidth, 270);
+        // But not exceeding 280
+        drawerWidth = Math.min(drawerWidth, 280);
 
         var disableEdgeSwipe = false;
 
@@ -1121,8 +1016,7 @@
             target: navDrawerElement,
             onChange: onMainDrawerSelect,
             width: drawerWidth,
-            disableEdgeSwipe: disableEdgeSwipe,
-            edgeSwipeElement: document.querySelector('.mainDrawerPanelContent')
+            disableEdgeSwipe: disableEdgeSwipe
         };
     }
 
@@ -1147,4 +1041,9 @@
 
     setDrawerClass();
 
+    //require(['appfooter-shared', 'dockedtabs'], function (footer, dockedtabs) {
+    //    new dockedtabs({
+    //        appFooter: footer
+    //    });
+    //});
 });
\ No newline at end of file
