@@ -1,4 +1,4 @@
-﻿define(['scripts/livetvcomponents', 'emby-button', 'listViewStyle'], function () {
+﻿define(['components/categorysyncbuttons', 'cardBuilder', 'scripts/livetvcomponents', 'emby-button', 'listViewStyle', 'emby-itemscontainer'], function (categorysyncbuttons, cardBuilder) {
 
     function getRecordingGroupHtml(group) {
 
@@ -70,18 +70,21 @@
 
         if (enableScrollX()) {
             recordingItems.classList.add('hiddenScrollX');
+            recordingItems.classList.remove('vertical-wrap');
         } else {
             recordingItems.classList.remove('hiddenScrollX');
+            recordingItems.classList.add('vertical-wrap');
         }
 
-        recordingItems.innerHTML = LibraryBrowser.getPosterViewHtml({
+        recordingItems.innerHTML = cardBuilder.getCardsHtml({
             items: recordings,
             shape: (enableScrollX() ? 'autooverflow' : 'auto'),
             showTitle: true,
             showParentTitle: true,
             coverImage: true,
             lazy: true,
-            cardLayout: true
+            cardLayout: true,
+            allowBottomPadding: !enableScrollX()
         });
 
         ImageLoader.lazyChildren(recordingItems);
@@ -149,7 +152,6 @@
             elem.querySelector('.recordingItems').innerHTML = html;
 
             ImageLoader.lazyChildren(elem);
-            LibraryBrowser.createCardMenus(elem);
         });
     }
 
@@ -185,6 +187,8 @@
 
         var self = this;
 
+        categorysyncbuttons.init(tabContent);
+
         tabContent.querySelector('#activeRecordings .recordingItems').addEventListener('timercancelled', function () {
             reload(tabContent);
         });
