@@ -1,8 +1,8 @@
-﻿define(['jQuery', 'libraryBrowser', 'scrollStyles'], function ($, libraryBrowser) {
+﻿define(['libraryBrowser', 'cardBuilder', 'dom', 'scrollStyles', 'emby-itemscontainer', 'emby-tabs', 'emby-button'], function (libraryBrowser, cardBuilder, dom) {
 
     function itemsPerRow() {
 
-        var screenWidth = $(window).width();
+        var screenWidth = dom.getWindowSize().innerWidth;
 
         return screenWidth >= 1920 ? 9 : (screenWidth >= 1200 ? 12 : (screenWidth >= 1000 ? 10 : 8));
     }
@@ -24,7 +24,7 @@
         var options = {
             IncludeItemTypes: "Audio",
             Limit: itemsPerRow(),
-            Fields: "PrimaryImageAspectRatio,SyncInfo",
+            Fields: "PrimaryImageAspectRatio,BasicSyncInfo",
             ParentId: parentId,
             ImageTypeLimit: 1,
             EnableImageTypes: "Primary,Backdrop,Banner,Thumb",
@@ -34,7 +34,7 @@
         ApiClient.getJSON(ApiClient.getUrl('Users/' + userId + '/Items/Latest', options)).then(function (items) {
 
             var elem = page.querySelector('#recentlyAddedSongs');
-            elem.innerHTML = libraryBrowser.getPosterViewHtml({
+            elem.innerHTML = cardBuilder.getCardsHtml({
                 items: items,
                 showUnplayedIndicator: false,
                 showLatestItemsPopup: false,
@@ -43,7 +43,8 @@
                 showParentTitle: true,
                 lazy: true,
                 centerText: true,
-                overlayPlayButton: true
+                overlayPlayButton: true,
+                allowBottomPadding: !enableScrollX()
 
             });
             ImageLoader.lazyChildren(elem);
@@ -61,7 +62,7 @@
             IncludeItemTypes: "Audio",
             Limit: itemsPerRow(),
             Recursive: true,
-            Fields: "PrimaryImageAspectRatio,AudioInfo,SyncInfo",
+            Fields: "PrimaryImageAspectRatio,AudioInfo",
             Filters: "IsPlayed",
             ParentId: parentId,
             ImageTypeLimit: 1,
@@ -71,25 +72,26 @@
 
         ApiClient.getItems(Dashboard.getCurrentUserId(), options).then(function (result) {
 
-            var elem;
+            var elem = page.querySelector('#recentlyPlayed');
 
             if (result.Items.length) {
-                elem = $('#recentlyPlayed', page).show()[0];
+                elem.classList.remove('hide');
             } else {
-                elem = $('#recentlyPlayed', page).hide()[0];
+                elem.classList.add('hide');
             }
 
             var itemsContainer = elem.querySelector('.itemsContainer');
-            itemsContainer.innerHTML = libraryBrowser.getPosterViewHtml({
+            itemsContainer.innerHTML = cardBuilder.getCardsHtml({
                 items: result.Items,
                 showUnplayedIndicator: false,
                 shape: getSquareShape(),
                 showTitle: true,
                 showParentTitle: true,
-                defaultAction: 'instantmix',
+                action: 'instantmix',
                 lazy: true,
                 centerText: true,
-                overlayMoreButton: true
+                overlayMoreButton: true,
+                allowBottomPadding: !enableScrollX()
 
             });
             ImageLoader.lazyChildren(itemsContainer);
@@ -107,7 +109,7 @@
             IncludeItemTypes: "Audio",
             Limit: itemsPerRow(),
             Recursive: true,
-            Fields: "PrimaryImageAspectRatio,AudioInfo,SyncInfo",
+            Fields: "PrimaryImageAspectRatio,AudioInfo",
             Filters: "IsPlayed",
             ParentId: parentId,
             ImageTypeLimit: 1,
@@ -117,25 +119,26 @@
 
         ApiClient.getItems(Dashboard.getCurrentUserId(), options).then(function (result) {
 
-            var elem;
+            var elem = page.querySelector('#topPlayed');
 
             if (result.Items.length) {
-                elem = $('#topPlayed', page).show()[0];
+                elem.classList.remove('hide');
             } else {
-                elem = $('#topPlayed', page).hide()[0];
+                elem.classList.add('hide');
             }
 
             var itemsContainer = elem.querySelector('.itemsContainer');
-            itemsContainer.innerHTML = libraryBrowser.getPosterViewHtml({
+            itemsContainer.innerHTML = cardBuilder.getCardsHtml({
                 items: result.Items,
                 showUnplayedIndicator: false,
                 shape: getSquareShape(),
                 showTitle: true,
                 showParentTitle: true,
-                defaultAction: 'instantmix',
+                action: 'instantmix',
                 lazy: true,
                 centerText: true,
-                overlayMoreButton: true
+                overlayMoreButton: true,
+                allowBottomPadding: !enableScrollX()
 
             });
             ImageLoader.lazyChildren(itemsContainer);
@@ -152,7 +155,7 @@
             SortOrder: "Ascending",
             IncludeItemTypes: "Playlist",
             Recursive: true,
-            Fields: "PrimaryImageAspectRatio,SortName,CumulativeRunTimeTicks,CanDelete,SyncInfo",
+            Fields: "PrimaryImageAspectRatio,SortName,CumulativeRunTimeTicks,CanDelete",
             StartIndex: 0,
             Limit: itemsPerRow(),
             EnableTotalRecordCount: false
@@ -160,16 +163,16 @@
 
         ApiClient.getItems(Dashboard.getCurrentUserId(), options).then(function (result) {
 
-            var elem;
+            var elem = page.querySelector('#playlists');
 
             if (result.Items.length) {
-                elem = $('#playlists', page).show()[0];
+                elem.classList.remove('hide');
             } else {
-                elem = $('#playlists', page).hide()[0];
+                elem.classList.add('hide');
             }
 
             var itemsContainer = elem.querySelector('.itemsContainer');
-            itemsContainer.innerHTML = libraryBrowser.getPosterViewHtml({
+            itemsContainer.innerHTML = cardBuilder.getCardsHtml({
                 items: result.Items,
                 shape: getSquareShape(),
                 showTitle: true,
@@ -177,7 +180,8 @@
                 coverImage: true,
                 showItemCounts: true,
                 centerText: true,
-                overlayPlayButton: true
+                overlayPlayButton: true,
+                allowBottomPadding: !enableScrollX()
 
             });
             ImageLoader.lazyChildren(itemsContainer);
@@ -243,22 +247,20 @@
             return browserInfo.mobile && AppInfo.enableAppLayouts;
         }
 
-        function getThumbShape() {
-            return enableScrollX() ? 'overflowBackdrop' : 'backdrop';
-        }
-
         self.initTab = function () {
 
             var tabContent = view.querySelector('.pageTabContent[data-index=\'' + 0 + '\']');
 
             var containers = tabContent.querySelectorAll('.itemsContainer');
-            if (enableScrollX()) {
-                $(containers).addClass('hiddenScrollX');
-            } else {
-                $(containers).removeClass('hiddenScrollX');
+            for (var i = 0, length = containers.length; i < length; i++) {
+                if (enableScrollX()) {
+                    containers[i].classList.add('hiddenScrollX');
+                    containers[i].classList.remove('vertical-wrap');
+                } else {
+                    containers[i].classList.remove('hiddenScrollX');
+                    containers[i].classList.add('vertical-wrap');
+                }
             }
-
-            $(containers).createCardMenus();
         };
 
         self.renderTab = function () {
@@ -268,9 +270,8 @@
         var tabControllers = [];
         var renderedTabs = [];
 
-        function loadTab(page, index) {
+        function getTabController(page, index, callback) {
 
-            var tabContent = page.querySelector('.pageTabContent[data-index=\'' + index + '\']');
             var depends = [];
 
             switch (index) {
@@ -281,15 +282,13 @@
                     depends.push('scripts/musicalbums');
                     break;
                 case 2:
-                    depends.push('scripts/musicalbumartists');
+                    depends.push('scripts/musicartists');
                     break;
                 case 3:
                     depends.push('scripts/musicartists');
                     break;
                 case 4:
                     depends.push('scripts/songs');
-                    depends.push('paper-icon-item');
-                    depends.push('paper-item-body');
                     break;
                 case 5:
                     depends.push('scripts/musicgenres');
@@ -302,13 +301,22 @@
             }
 
             require(depends, function (controllerFactory) {
-
+                var tabContent;
                 if (index == 0) {
+                    tabContent = view.querySelector('.pageTabContent[data-index=\'' + index + '\']');
                     self.tabContent = tabContent;
                 }
                 var controller = tabControllers[index];
                 if (!controller) {
+                    tabContent = view.querySelector('.pageTabContent[data-index=\'' + index + '\']');
                     controller = index ? new controllerFactory(view, params, tabContent) : self;
+
+                    if (index == 2) {
+                        controller.mode = 'albumartists';
+                    } else if (index == 3) {
+                        controller.mode = 'artists';
+                    }
+
                     tabControllers[index] = controller;
 
                     if (controller.initTab) {
@@ -316,6 +324,24 @@
                     }
                 }
 
+                callback(controller);
+            });
+        }
+
+        function preLoadTab(page, index) {
+
+            getTabController(page, index, function (controller) {
+                if (renderedTabs.indexOf(index) == -1) {
+                    if (controller.preRender) {
+                        controller.preRender();
+                    }
+                }
+            });
+        }
+
+        function loadTab(page, index) {
+
+            getTabController(page, index, function (controller) {
                 if (renderedTabs.indexOf(index) == -1) {
                     renderedTabs.push(index);
                     controller.renderTab();
@@ -323,22 +349,29 @@
             });
         }
 
-        var mdlTabs = view.querySelector('.libraryViewNav');
+        var viewTabs = view.querySelector('.libraryViewNav');
 
-        var baseUrl = 'music.html';
-        var topParentId = params.topParentId;
-        if (topParentId) {
-            baseUrl += '?topParentId=' + topParentId;
-        }
+        libraryBrowser.configurePaperLibraryTabs(view, viewTabs, view.querySelectorAll('.pageTabContent'), [0, 4, 5, 6]);
 
-        libraryBrowser.configurePaperLibraryTabs(view, mdlTabs, view.querySelectorAll('.pageTabContent'), [0, 4, 5, 6]);
-
-        mdlTabs.addEventListener('tabchange', function (e) {
+        viewTabs.addEventListener('beforetabchange', function (e) {
+            preLoadTab(view, parseInt(e.detail.selectedTabIndex));
+        });
+        viewTabs.addEventListener('tabchange', function (e) {
             loadTab(view, parseInt(e.detail.selectedTabIndex));
         });
 
+        if (AppInfo.enableHeadRoom) {
+            require(["headroom-window"], function (headroom) {
+                headroom.add(viewTabs);
+                self.headroom = headroom;
+            });
+        }
+
         view.addEventListener('viewdestroy', function (e) {
 
+            if (self.headroom) {
+                self.headroom.remove(viewTabs);
+            }
             tabControllers.forEach(function (t) {
                 if (t.destroy) {
                     t.destroy();
