@@ -679,7 +679,8 @@ var Dashboard = {
         if (setQuality) {
             var quality = 90;
 
-            if ((options.type || '').toLowerCase() == 'backdrop') {
+            var isBackdrop = (options.type || '').toLowerCase() == 'backdrop';
+            if (isBackdrop) {
                 quality -= 10;
             }
 
@@ -687,15 +688,9 @@ var Dashboard = {
                 quality -= 40;
             }
 
-            if (AppInfo.hasLowImageBandwidth) {
+            if (AppInfo.hasLowImageBandwidth && !isBackdrop) {
 
-                // The native app can handle a little bit more than safari
-                if (AppInfo.isNativeApp) {
-
-                    quality -= 10;
-                } else {
-                    quality -= 20;
-                }
+                quality -= 10;
             }
             options.quality = quality;
         }
@@ -1234,7 +1229,7 @@ var AppInfo = {};
             inputManager: embyWebComponentsBowerPath + "/inputmanager",
             qualityoptions: embyWebComponentsBowerPath + "/qualityoptions",
             hammer: bowerPath + "/hammerjs/hammer.min",
-            pageJs: embyWebComponentsBowerPath + '/page.js/page',
+            pageJs: embyWebComponentsBowerPath + '/pagejs/page',
             focusManager: embyWebComponentsBowerPath + "/focusmanager",
             datetime: embyWebComponentsBowerPath + "/datetime",
             globalize: embyWebComponentsBowerPath + "/globalize",
@@ -1403,6 +1398,7 @@ var AppInfo = {};
 
         define('fetch', [bowerPath + '/fetch/fetch']);
 
+        define('raf', [embyWebComponentsBowerPath + '/polyfills/raf']);
         define('functionbind', [embyWebComponentsBowerPath + '/polyfills/bind']);
         define('arraypolyfills', [embyWebComponentsBowerPath + '/polyfills/array']);
         define('objectassign', [embyWebComponentsBowerPath + '/polyfills/objectassign']);
@@ -1801,6 +1797,10 @@ var AppInfo = {};
             list.push('functionbind');
         }
 
+        if (!window.requestAnimationFrame) {
+            list.push('raf');
+        }
+
         require(list, function () {
 
             createConnectionManager().then(function () {
@@ -1975,7 +1975,6 @@ var AppInfo = {};
 
         defineRoute({
             path: '/dashboardgeneral.html',
-            dependencies: ['emby-collapse', 'emby-textarea', 'emby-input', 'paper-checkbox'],
             controller: 'dashboard/dashboardgeneral',
             autoFocus: false,
             roles: 'admin'
@@ -2151,7 +2150,7 @@ var AppInfo = {};
 
         defineRoute({
             path: '/librarydisplay.html',
-            dependencies: ['emby-button', 'paper-checkbox'],
+            dependencies: [],
             autoFocus: false,
             roles: 'admin',
             controller: 'dashboard/librarydisplay'
@@ -2805,8 +2804,12 @@ var AppInfo = {};
                     return navigator.serviceWorker.ready;
                 }).then(function (reg) {
 
-                    // https://github.com/WICG/BackgroundSync/blob/master/explainer.md
-                    return reg.sync.register('emby-sync');
+                    if (reg.sync) {
+                        // https://github.com/WICG/BackgroundSync/blob/master/explainer.md
+                        return reg.sync.register('emby-sync').then(function () {
+                            window.SyncRegistered = Dashboard.isConnectMode();
+                        });
+                    }
                 });
 
             } catch (err) {
